Stan Math Library: stan/math/prim/scal/fun/ibeta.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

ibeta.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_SCAL_FUN_IBETA_HPP
2 #define STAN_MATH_PRIM_SCAL_FUN_IBETA_HPP
3
4 #include <boost/math/special_functions/beta.hpp>
5 #include <stan/math/prim/scal/err/check_not_nan.hpp>
6
7 namespace stan {
8 namespace math {
9
23 inline double ibeta(const double a,
24 const double b,
25 const double x) {
26 using stan::math::check_not_nan;
27
28 check_not_nan("ibeta", "a", a);
29 check_not_nan("ibeta", "b", b);
30 check_not_nan("ibeta", "x", x);
31 return boost::math::ibeta(a, b, x);
32 }
33
34 }
35 }
36
37 #endif
check_not_nan.hpp
stan::math::ibeta
double ibeta(const double a, const double b, const double x)
The normalized incomplete beta function of a, b, and x.
Definition: ibeta.hpp:23
stan::math::check_not_nan
bool check_not_nan(const char *function, const char *name, const T_y &y)
Return true if y is not NaN.
Definition: check_not_nan.hpp:63
stan
Definition: log_sum_exp.hpp:8
stan::math::ibeta
var ibeta(const var &a, const var &b, const var &x)
The normalized incomplete beta function of a, b, and x.
Definition: ibeta.hpp:238

[ Stan Home Page ] © 2011–2016, Stan Development Team.